
Reference converters
====================

Summary
-------

.. autosummary::

	bioconvert.abi2fasta
	bioconvert.abi2fastq
	bioconvert.abi2qual
	bioconvert.bam2bedgraph
	bioconvert.bam2cov
	bioconvert.bam2bigwig
	bioconvert.bam2cram
	bioconvert.bam2fasta
	bioconvert.bam2fastq
	bioconvert.bam2json
	bioconvert.bam2sam
	bioconvert.bam2tsv
	bioconvert.bam2wiggle
	bioconvert.bcf2vcf
	bioconvert.bcf2wiggle
	bioconvert.bed2wiggle
	bioconvert.bedgraph2cov
	bioconvert.bedgraph2bigwig
	bioconvert.bedgraph2wiggle
	bioconvert.bigbed2wiggle
	bioconvert.bigbed2bed
	bioconvert.bigwig2bedgraph
	bioconvert.bigwig2wiggle
	bioconvert.bplink2plink
	bioconvert.bz22gz
	bioconvert.clustal2fasta
	bioconvert.clustal2phylip
	bioconvert.clustal2stockholm
	bioconvert.cram2bam
	bioconvert.cram2fasta
	bioconvert.cram2fastq
	bioconvert.cram2sam
	bioconvert.csv2tsv
	bioconvert.csv2xls
	bioconvert.dsrc2gz
	bioconvert.embl2fasta
	bioconvert.embl2genbank
	bioconvert.fasta_qual2fastq
	bioconvert.fasta2clustal
	bioconvert.fasta2faa
	bioconvert.fasta2fastq
	bioconvert.fasta2genbank
	bioconvert.fasta2nexus
	bioconvert.fasta2phylip
	bioconvert.fasta2twobit
	bioconvert.fastq2fasta
	bioconvert.genbank2embl
	bioconvert.genbank2fasta
	bioconvert.genbank2gff3
	bioconvert.gff22gff3
	bioconvert.gff32gff2
	bioconvert.gfa2fasta
	bioconvert.gz2bz2
	bioconvert.gz2dsrc
	bioconvert.json2yaml
	bioconvert.maf2sam
	bioconvert.newick2nexus
	bioconvert.newick2phyloxml
	bioconvert.nexus2fasta
	bioconvert.nexus2newick
	bioconvert.nexus2phylip
	bioconvert.nexus2phyloxml
	bioconvert.ods2csv
	bioconvert.phylip2clustal
	bioconvert.phylip2fasta
	bioconvert.phylip2nexus
	bioconvert.phylip2stockholm
	bioconvert.phylip2xmfa
	bioconvert.phyloxml2newick
	bioconvert.phyloxml2nexus
	bioconvert.plink2bplink
	bioconvert.sam2bam
	bioconvert.sam2cram
	bioconvert.sam2paf
	bioconvert.scf2fasta
	bioconvert.scf2fastq
	bioconvert.sra2fastq
	bioconvert.stockholm2clustal
	bioconvert.stockholm2phylip
	bioconvert.tsv2csv
	bioconvert.twobit2fasta
	bioconvert.vcf2bcf
	bioconvert.vcf2bed
	bioconvert.vcf2wiggle
	bioconvert.xls2csv
	bioconvert.xlsx2csv
	bioconvert.xmfa2phylip
	bioconvert.yaml2json

All converters documentation
----------------------------



.. automodule:: bioconvert.abi2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.abi2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.abi2qual
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2bedgraph
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2cov
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2bigwig
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2cram
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2json
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2sam
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2tsv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bam2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bcf2vcf
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bcf2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bed2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bedgraph2cov
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bedgraph2bigwig
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bedgraph2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bigbed2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule::	bioconvert.bigbed2bed
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bigwig2bedgraph
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bigwig2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bplink2plink
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.bz22gz
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.clustal2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.clustal2phylip
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.clustal2stockholm
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.cram2bam
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.cram2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.cram2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.cram2sam
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.csv2tsv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.csv2xls
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.dsrc2gz
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.embl2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.embl2genbank
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta_qual2fastq
    :members:
    :synopsis:
    :private-members:


.. automodule:: bioconvert.fasta2clustal
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2faa
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2genbank
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2nexus
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2phylip
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fasta2twobit
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.fastq2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.genbank2embl
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.genbank2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.genbank2gff3
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.gff22gff3
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.gff32gff2
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.gfa2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.gz2bz2
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.gz2dsrc
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.json2yaml
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.maf2sam
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.newick2nexus
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.newick2phyloxml
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.nexus2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.nexus2newick
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.nexus2phylip
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.nexus2phyloxml
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.ods2csv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phylip2clustal
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phylip2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phylip2nexus
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phylip2stockholm
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phylip2xmfa
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phyloxml2newick
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.phyloxml2nexus
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.plink2bplink
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.sam2bam
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.sam2cram
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.sam2paf
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.scf2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.scf2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.sra2fastq
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.stockholm2clustal
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.stockholm2phylip
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.tsv2csv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.twobit2fasta
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.vcf2bcf
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.vcf2bed
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.vcf2wiggle
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.xls2csv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.xlsx2csv
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.xmfa2phylip
    :members:
    :synopsis:
    :private-members:

.. automodule:: bioconvert.yaml2json
    :members:
    :synopsis:
    :private-members:
